@@ -35,7 +35,8 @@
 #include <gpe/pim-categories-ui.h>
 #include <hildon-fm/hildon-widgets/hildon-file-chooser-dialog.h>
 #include <libosso.h>
-#define APPLICATION_DBUS_SERVICE "gpe-calendar"
+#define APPLICATION_DBUS_SERVICE "gpe_calendar"
+#define ICON_PATH "/usr/share/icons/hicolor/26x26/hildon"
 #endif
 
 #include "event-ui.h"
@@ -45,6 +46,7 @@
 #include "week_view.h"
 #include "month_view.h"
 #include "import-vcal.h"
+#include "export-vcal.h"
 #include "gtkdatesel.h"
 
 #include <gpe/pim-categories.h>
@@ -61,17 +63,17 @@ gboolean force_today = FALSE;
 gboolean just_new = FALSE;
 
 GtkWidget *main_window, *pop_window;
-GtkWidget *notebook;
+GtkWidget *notebook, *toolbar;
 extern GtkWidget* day_list;
 
 struct gpe_icon my_icons[] = {
-  { "day_view", "day_view" },
-  { "week_view", "week_view" },
-  { "month_view", "month_view" },
-  { "bell", "bell" },
-  { "recur", "recur" },
-  { "bell_recur", "bell_recur" },
-  { "icon", PREFIX "/share/pixmaps/gpe-calendar.png" },
+  { "day_view",   DAY_ICON },
+  { "week_view",  WEEK_ICON },
+  { "month_view", MONTH_ICON },
+  { "bell",        BELL_ICON },
+  { "recur",       RECUR_ICON },
+  { "bell_recur", BELLRECUR_ICON },
+  { "icon", APP_ICON },
   { NULL, NULL }
 };
 
@@ -262,6 +264,37 @@ gpe_cal_exit (void)
   gtk_main_quit ();
 }
 
+#ifdef IS_HILDON
+static void
+gpe_cal_fullscreen_toggle (void)
+{
+  static int fullscreen_toggle = TRUE;
+  hildon_appview_set_fullscreen(HILDON_APPVIEW(main_window), fullscreen_toggle);
+  fullscreen_toggle = !fullscreen_toggle;
+}
+
+static void
+toggle_toolbar(GtkCheckMenuItem *menuitem, gpointer user_data)
+{
+  if (gtk_check_menu_item_get_active(menuitem))
+    gtk_widget_show(toolbar);
+  else
+    gtk_widget_hide(toolbar);
+}
+
+static void
+edit_categories (GtkWidget *w)
+{
+  GtkWidget *dialog;
+
+  dialog = gpe_pim_categories_dialog (NULL, FALSE, NULL, NULL);
+  gtk_window_set_transient_for(GTK_WINDOW(dialog), 
+                               GTK_WINDOW(gtk_widget_get_toplevel(w)));
+  gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
+}
+
+#endif /*IS_HILDON*/
+
 static int 
 import_one_file(gchar *filename)
 {
@@ -285,15 +318,24 @@ on_import_vcal (GtkWidget *widget, gpointer data)
 {
   GtkWidget *filesel, *feedbackdlg;
   
+#if IS_HILDON	
+  filesel = hildon_file_chooser_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(widget)), 
+                                                      GTK_FILE_CHOOSER_ACTION_OPEN);
+  gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(filesel), TRUE);
+#else
   filesel = gtk_file_selection_new(_("Choose file"));
   gtk_file_selection_set_select_multiple(GTK_FILE_SELECTION(filesel),TRUE);
-  
+#endif	
   if (gtk_dialog_run(GTK_DIALOG(filesel)) == GTK_RESPONSE_OK)
     {
       gchar *errstr = NULL;
       int ec = 0, i = 0;
+#ifdef IS_HILDON
+      gchar **files = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(filesel));
+#else		
       gchar **files = 
         gtk_file_selection_get_selections(GTK_FILE_SELECTION(filesel));
+#endif
       gtk_widget_hide(filesel); 
       while (files[i])
         {
@@ -311,11 +353,11 @@ on_import_vcal (GtkWidget *widget, gpointer data)
           i++;  
         }
       if (ec)
-        feedbackdlg = gtk_message_dialog_new(GTK_WINDOW(main_window),
+        feedbackdlg = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(main_window)),
           GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, 
           "%s %i %s\n%s",_("Import of"),ec,_("files failed:"),errstr);
       else
-        feedbackdlg = gtk_message_dialog_new(GTK_WINDOW(main_window),
+        feedbackdlg = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(main_window)),
           GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, 
           _("Import successful"));
       gtk_dialog_run(GTK_DIALOG(feedbackdlg));
@@ -342,6 +384,16 @@ notebook_switch_page (GtkNotebook *notebook,
 static gboolean
 main_window_key_press_event (GtkWidget *widget, GdkEventKey *k, GtkWidget *data)
 {
+#ifdef IS_HILDON
+    /* in hildon there is nothing like control, shift etc buttons */
+    switch (k->keyval)
+      {
+        case GDK_F6:
+        /* toggle button for going full screen */
+        gpe_cal_fullscreen_toggle();
+        break;	
+      }
+#else
   if (k->state & GDK_CONTROL_MASK)
     switch (k->keyval)
       {
@@ -359,6 +411,7 @@ main_window_key_press_event (GtkWidget *widget, GdkEventKey *k, GtkWidget *data)
           gpe_cal_exit();
         break;	
       }
+#endif /*IS_HILDON*/
   /* ignore if ctrl or alt pressed */    
   if ((k->state & GDK_CONTROL_MASK) 
        || (k->state & GDK_MOD1_MASK))
@@ -382,8 +435,8 @@ static void
 create_app_menu(HildonAppView *appview)
 {
   GtkMenu *main_menu;
-  GtkWidget *item_appointment, *item_today, *item_day, *item_week,
-    *item_month, *item_import, *item_toolbar;
+  GtkWidget *item_appointment, *item_today, *item_import, *item_toolbar, 
+            *item_sep, *item_close, *item_cat;
 
   main_menu = hildon_appview_get_menu(appview);
 
@@ -399,14 +452,30 @@ create_app_menu(HildonAppView *appview)
   g_signal_connect(G_OBJECT(item_import), "activate", G_CALLBACK(on_import_vcal), NULL);
   gtk_menu_append(main_menu, item_import);
 
-  gtk_widget_show_all(main_menu);
+  item_toolbar = gtk_check_menu_item_new_with_label(_("Show toolbar"));
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item_toolbar), TRUE);
+  g_signal_connect(G_OBJECT(item_toolbar), "activate", G_CALLBACK(toggle_toolbar), NULL);
+  gtk_menu_append(main_menu, item_toolbar);
+    
+  item_cat = gtk_menu_item_new_with_label(_("Edit catgories"));
+  g_signal_connect(G_OBJECT(item_cat), "activate", G_CALLBACK(edit_categories), NULL);
+  gtk_menu_append(main_menu, item_cat);
+  
+  item_sep = gtk_separator_menu_item_new();
+  gtk_menu_append(main_menu, item_sep);
+  
+  item_close = gtk_menu_item_new_with_label(_("Quit"));
+  g_signal_connect(G_OBJECT(item_close), "activate", G_CALLBACK(gpe_cal_exit), NULL);
+  gtk_menu_append(main_menu, item_close);
+
+  gtk_widget_show_all(GTK_WIDGET(main_menu));
 }
 #endif
 	 
 int
 main (int argc, char *argv[])
 {
-  GtkWidget *vbox, *toolbar;
+  GtkWidget *vbox;
   GdkPixbuf *p;
   GtkWidget *pw;
   GtkToolItem *item;
@@ -493,6 +562,8 @@ main (int argc, char *argv[])
       times = g_list_append (times, g_strdup (buf));
     }
 
+  vcal_export_init();
+    
   vbox = gtk_vbox_new (FALSE, 0);
   notebook = gtk_notebook_new ();
 
@@ -508,6 +579,8 @@ main (int argc, char *argv[])
   main_appview = hildon_appview_new(_("Main"));
   hildon_app_set_appview(HILDON_APP(app), HILDON_APPVIEW(main_appview));
   main_window = main_appview;
+  
+  gtk_notebook_set_show_border(GTK_NOTEBOOK(notebook), FALSE);
 #else    
   main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (main_window), _("Calendar"));
@@ -520,8 +593,7 @@ main (int argc, char *argv[])
 
 #ifdef IS_HILDON
   /* Initialize maemo application */
-  osso_context = osso_initialize(
-  APPLICATION_DBUS_SERVICE, "0.1", TRUE, NULL);
+  osso_context = osso_initialize(APPLICATION_DBUS_SERVICE, "0.1", TRUE, NULL);
 
   /* Check that initialization was ok */
   if (osso_context == NULL)
@@ -544,10 +616,11 @@ main (int argc, char *argv[])
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar), GTK_ORIENTATION_HORIZONTAL);
   GTK_WIDGET_UNSET_FLAGS(toolbar, GTK_CAN_FOCUS);
 
-#ifndef IS_HILDON
-  gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
-#else
+#ifdef IS_HILDON
   hildon_appview_set_toolbar(HILDON_APPVIEW(main_appview), GTK_TOOLBAR(toolbar));
+  gtk_widget_show_all(main_appview);
+#else
+  gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
 #endif
   gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
 
@@ -622,6 +695,13 @@ main (int argc, char *argv[])
   GTK_WIDGET_UNSET_FLAGS(item, GTK_CAN_FOCUS);
   month_button = GTK_WIDGET(item);    
   
+  if (window_x > 260)
+    {	  
+      item = gtk_separator_tool_item_new();
+      gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(item), FALSE);
+      gtk_toolbar_insert(GTK_TOOLBAR(toolbar), item, -1);
+    }
+  
   pw = gtk_image_new_from_stock(GTK_STOCK_OPEN, 
                                 gtk_toolbar_get_icon_size(GTK_TOOLBAR (toolbar)));
   item = gtk_tool_button_new(pw, _("Import"));
@@ -631,7 +711,13 @@ main (int argc, char *argv[])
                        _("Open file to import an event from it."), NULL);
   GTK_WIDGET_UNSET_FLAGS(item, GTK_CAN_FOCUS);
 
-#ifndef IS_HILDON
+#ifdef IS_HILDON
+  pw = gtk_image_new_from_file(ICON_PATH "/qgn_list_gene_bullets.png");
+  item = gtk_tool_button_new(pw, _("Categories"));
+  g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK (edit_categories), 
+                       NULL);
+  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), item, -1);
+#else
   item = gtk_separator_tool_item_new();
   gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(item), FALSE);
   gtk_tool_item_set_expand(item, TRUE);
@@ -643,11 +729,10 @@ main (int argc, char *argv[])
   gtk_tooltips_set_tip(tooltips, GTK_WIDGET(item), 
                        _("Tap here to exit the program"), NULL);
   GTK_WIDGET_UNSET_FLAGS(item, GTK_CAN_FOCUS);
-  
 #endif
 
 #ifdef IS_HILDON
-  create_app_menu(main_appview);
+  create_app_menu(HILDON_APPVIEW(main_appview));
 #endif
 	 
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
@@ -664,15 +749,19 @@ main (int argc, char *argv[])
                    G_CALLBACK(notebook_switch_page),NULL);
   g_signal_connect (G_OBJECT (main_window), "key_press_event", 
 		    G_CALLBACK (main_window_key_press_event), NULL);
+#ifndef IS_HILDON
+  /* in case of hildon we use default behavious */
   gtk_widget_add_events (GTK_WIDGET (main_window), 
                          GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
-
+						 
+  gpe_set_window_icon (main_window, "icon");
+#endif /*IS_HILDON*/
+  
   gtk_widget_show (notebook);
 
-  gpe_set_window_icon (main_window, "icon");
-
 #ifdef IS_HILDON  
-  gtk_widget_show_all(app);
+  gtk_widget_show(app);
+  gtk_widget_show(main_appview);
 #endif
   gtk_widget_show (main_window);
   gtk_widget_show (vbox);
